datastructuretools.TypedOrderedDict
===================================

.. abjad-lineage:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict

.. autoclass:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.clear
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.copy
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.get
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.has_key
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.item_class
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.items
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.keys
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.pop
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.popitem
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.setdefault
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.update
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.values
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__cmp__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__contains__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__delitem__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__eq__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__format__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__ge__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__getitem__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__gt__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__hash__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__iter__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__le__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__len__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__lt__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__ne__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__repr__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__reversed__
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__setitem__

Bases
-----

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.item_class
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.clear
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.copy
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.get
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.has_key
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.items
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.keys
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.pop
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.popitem
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.setdefault
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.update
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.values
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__cmp__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__delitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__reversed__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict.__setitem__
   :noindex:
